==> unixODBC-1.8.13.tar.gz: unixODBC-1.8.13/Drivers/txt/SQLFetch.c <==
/**********************************************************************
 * SQLFetch
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 **********************************************************************/

#include "driver.h"

SQLRETURN SQLFetch( SQLHSTMT  hDrvStmt)
{
    HDRVSTMT 		hStmt		= (HDRVSTMT)hDrvStmt;
	HBOUNDCOLUMN	pColumnHeader;			
	int				nCol;

	/* SANITY CHECKS */
	if ( !hStmt )
		return SQL_INVALID_HANDLE;

	sprintf( hStmt->szSqlMsg, "hStmt = $%08lX", hStmt );
	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );

	if ( !hStmt->hStmtExtras->hBoundCols )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No result set." );
		return SQL_ERROR;
	}

	if ( hStmt->hStmtExtras->hStmt->hTableResult->hRows->nItems < 1 )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No result set." );
		return SQL_ERROR;
	}

	/************************
	 * POS (new result sets should be position at EOL... hCurrent=NULL )
	 ************************/
    if ( lstEOL( hStmt->hStmtExtras->hStmt->hTableResult->hRows ) )
	{
		lstFirst( hStmt->hStmtExtras->hStmt->hTableResult->hRows );
	}
	else
		lstNext( hStmt->hStmtExtras->hStmt->hTableResult->hRows );

    if ( lstEOL( hStmt->hStmtExtras->hStmt->hTableResult->hRows ) )
		return SQL_NO_DATA;

	/************************
	 * transfer bound column values to bound storage as required
	 ************************/
	nCol = 0;
	lstFirst( hStmt->hStmtExtras->hBoundCols );
	while ( !lstEOL( hStmt->hStmtExtras->hBoundCols ) )
	{
		pColumnHeader = (HBOUNDCOLUMN)lstGet( hStmt->hStmtExtras->hBoundCols );
		if ( pColumnHeader->pTargetValue != NULL )
		{
			if ( _GetData(	hDrvStmt,
							nCol,
							pColumnHeader->nTargetType,
							pColumnHeader->pTargetValue,
							pColumnHeader->nTargetValueMax,
							pColumnHeader->pnLengthOrIndicator ) != SQL_SUCCESS )
			{
				sprintf( hStmt->szSqlMsg, "SQL_ERROR Failed to get data for column %d", nCol );
				logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );
				return SQL_ERROR;
			}
		}
		nCol++;
		lstNext( hStmt->hStmtExtras->hBoundCols );
	}

	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_INFO, LOG_INFO, "SQL_SUCCESS" );
	return SQL_SUCCESS;
}

==> unixODBC-2.0.5.tar.gz: unixODBC-2.0.5/Drivers/txt/SQLFetch.c <==
/**********************************************************************
 * SQLFetch
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 **********************************************************************/

#include "driver.h"

SQLRETURN SQLFetch( SQLHSTMT  hDrvStmt)
{
    HDRVSTMT 		hStmt		= (HDRVSTMT)hDrvStmt;
	HBOUNDCOLUMN	pColumnHeader;			
	int				nCol;

	/* SANITY CHECKS */
	if ( !hStmt )
		return SQL_INVALID_HANDLE;

	sprintf( hStmt->szSqlMsg, "hStmt = $%08lX", hStmt );
	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );

	if ( !hStmt->hTable )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No result set." );
		return SQL_ERROR;
	}

	/************************
	 * POS (new result sets should be position at EOL... hCurrent=NULL )
	 ************************/
    if ( lstEOL( hStmt->hTable->hRows ) )
	{
		lstFirst( hStmt->hTable->hRows );
	}
	else
		lstNext( hStmt->hTable->hRows );

    if ( lstEOL( hStmt->hTable->hRows ) )
		return SQL_NO_DATA;

	/************************
	 * transfer bound column values to bound storage as required
	 ************************/
	nCol = 0;
	lstFirst( hStmt->hBoundCols );
	while ( !lstEOL( hStmt->hBoundCols ) )
	{
		pColumnHeader = (HBOUNDCOLUMN)lstGet( hStmt->hBoundCols );
		if ( pColumnHeader->pTargetValue != NULL )
		{
			if ( SQLGetData_(	hDrvStmt,
							pColumnHeader->hColumn,
							pColumnHeader->nTargetType,
							pColumnHeader->pTargetValue,
							pColumnHeader->nTargetValueMax,
							pColumnHeader->pnLengthOrIndicator ) != SQL_SUCCESS )
			{
				sprintf( hStmt->szSqlMsg, "SQL_ERROR Failed to get data for column %d", nCol );
				logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );
				return SQL_ERROR;
			}
		}
		nCol++;
		lstNext( hStmt->hBoundCols );
	}

	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_INFO, LOG_INFO, "SQL_SUCCESS" );
	return SQL_SUCCESS;
}
